Struct TalentDescriptionValuesCtx

pub struct TalentDescriptionValuesCtx<'a> {
    pub talent_level: i64,
    pub script: &'a str,
}
Inputs available to a talent_description_values native fn — the same two TalentLevel constant and the script source (the multipliers N live in the source text). The scope_setter for this slot is the identity closure (compute_description_values_for_talent), so there are no other scope variables to mirror.

Fields

talent_level: i64script: &'a str